task vcf2maf {

  File vcf
  String basename = basename(vcf,".vcf")
  String tumor_id
  String normal_id
  File ref_dir
  String fasta
  String vep_path
  File cache
  String ncbi_build
  String species
  Boolean only_pass
  String docker
  String cluster_config
  String disk_size


  command <<<
    set -o pipefail
    set -e
    nt=$(nproc)

    if [ only_pass ]; then
    awk -F'\t' '{if(($1~"^#")||($1!~"^#" && $7=="PASS")){print $0}}' ${vcf} > input_vcf
    else
    cat ${vcf} > input_vcf
    fi

    perl /opt/mskcc-vcf2maf/vcf2maf.pl \
    --input-vcf $input_vcf --output-maf ${basename}.maf \
    --tumor-id ${tumor_id} --normal-id ${normal_id} \
    --ref-fasta ${ref_dir}/${fasta} \
    --vep-path ${vep_path} \
    --vep-data ${cache} \
    --ncbi-build ${ncbi_build} \
    --species ${species} \
    --vep-fork $nt
  >>>
  
  runtime {
    docker: docker
    cluster: cluster_config
    systemDisk: "cloud_ssd 40"
    dataDisk: "cloud_ssd " + disk_size + " /cromwell_root/"
  }

  output {
    File maf = "${basename}.maf"
  }
}